==> haskell-openpgp-asciiarmor-0.1.2-300-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-openpgp-asciiarmor.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 openpgp-asciiarmor
version:              0.1.2
visibility:           public
id:                   openpgp-asciiarmor-0.1.2-F0M3QJO81TMEluJfxCHyz6
key:                  openpgp-asciiarmor-0.1.2-F0M3QJO81TMEluJfxCHyz6
license:              MIT
copyright:            2012-2019 Clint Adams
maintainer:           Clint Adams <clint@debian.org>
author:               Clint Adams
homepage:             http://floss.scru.org/openpgp-asciiarmor
synopsis:             OpenPGP (RFC4880) ASCII Armor codec
description:          OpenPGP (RFC4880) ASCII Armor codec
category:             Codec, Data
abi:                  7ffcfdabef62ff51dfd1acb9d28a3ba0
exposed:              True
exposed-modules:
    Codec.Encryption.OpenPGP.ASCIIArmor
    Codec.Encryption.OpenPGP.ASCIIArmor.Decode
    Codec.Encryption.OpenPGP.ASCIIArmor.Encode
    Codec.Encryption.OpenPGP.ASCIIArmor.Types

hidden-modules:
    Data.Digest.CRC24 Codec.Encryption.OpenPGP.ASCIIArmor.Multipart
    Codec.Encryption.OpenPGP.ASCIIArmor.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/openpgp-asciiarmor-0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/openpgp-asciiarmor-0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/openpgp-asciiarmor-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-openpgp-asciiarmor
hs-libraries:         HSopenpgp-asciiarmor-0.1.2-F0M3QJO81TMEluJfxCHyz6
depends:
    attoparsec-0.14.4-7XWZ3nsZOGKJDEorzXp6qF base-4.17.2.1
    base64-bytestring-1.2.1.0-3xTWh9pwP9a781vByOHbcb binary-0.8.9.1
    bytestring-0.11.5.3

haddock-interfaces:
    /usr/share/doc/haskell-openpgp-asciiarmor/html/openpgp-asciiarmor.haddock

haddock-html:         /usr/share/doc/haskell-openpgp-asciiarmor/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-openpgp-asciiarmor-0.1.2-301-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-openpgp-asciiarmor.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 openpgp-asciiarmor
version:              0.1.2
visibility:           public
id:                   openpgp-asciiarmor-0.1.2-2Thl4Zg3NcdIvqHrwixx0O
key:                  openpgp-asciiarmor-0.1.2-2Thl4Zg3NcdIvqHrwixx0O
license:              MIT
copyright:            2012-2019 Clint Adams
maintainer:           Clint Adams <clint@debian.org>
author:               Clint Adams
homepage:             http://floss.scru.org/openpgp-asciiarmor
synopsis:             OpenPGP (RFC4880) ASCII Armor codec
description:          OpenPGP (RFC4880) ASCII Armor codec
category:             Codec, Data
abi:                  4556e675a04250f863229a41a0051a6f
exposed:              True
exposed-modules:
    Codec.Encryption.OpenPGP.ASCIIArmor
    Codec.Encryption.OpenPGP.ASCIIArmor.Decode
    Codec.Encryption.OpenPGP.ASCIIArmor.Encode
    Codec.Encryption.OpenPGP.ASCIIArmor.Types

hidden-modules:
    Data.Digest.CRC24 Codec.Encryption.OpenPGP.ASCIIArmor.Multipart
    Codec.Encryption.OpenPGP.ASCIIArmor.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/openpgp-asciiarmor-0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/openpgp-asciiarmor-0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/openpgp-asciiarmor-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-openpgp-asciiarmor
hs-libraries:         HSopenpgp-asciiarmor-0.1.2-2Thl4Zg3NcdIvqHrwixx0O
depends:
    attoparsec-0.14.4-LYMz7sGPlLCLdIXUlDCVP9 base-4.17.2.1
    base64-bytestring-1.2.1.0-3xTWh9pwP9a781vByOHbcb binary-0.8.9.1
    bytestring-0.11.5.3

haddock-interfaces:
    /usr/share/doc/haskell-openpgp-asciiarmor/html/openpgp-asciiarmor.haddock

haddock-html:         /usr/share/doc/haskell-openpgp-asciiarmor/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
